@@ -1,6 +1,6 @@
 /***
 |''Name''|BinaryUploadPlugin|
-|''Version''|0.3.11|
+|''Version''|0.3.12|
 |''Author''|Ben Gillies and Jon Robson|
 |''Type''|plugin|
 |''Source''|http://github.com/TiddlySpace/tiddlyspace/raw/master/src/plugins/BinaryUploadPlugin.js|
@@ -74,9 +74,12 @@ var macro = config.macros.binaryUpload = {
 		fileName = fileName.substr(fStart+1);
 		return fileName;
 	},
+	errorHandler: function(fileName) {
+		displayMessage("upload of file %0 failed".format([fileName]));
+	},
 	uploadFile: function(place, baseURL, workspace, options) {
 		var pleaseWait = $(".uploadProgress", place);
-		var iframeName = $("iframe", place).attr("name");
+		var iframeName = options.target;
 		var form = $("form", place);
 		var existingVal = $("input[name=title]", form).val();
 		var fileName = existingVal || $('input:file', form).val();
@@ -86,7 +89,7 @@ var macro = config.macros.binaryUpload = {
 		fileName = macro.getTiddlerName(fileName);
 		$("input[name=title]", place).val(fileName);
 		// we need to go somewhere afterwards to ensure the onload event triggers
-		var redirectTo = "/%1/tiddlers.txt?select=title:%2".
+		var redirectTo = "/%0/tiddlers.txt?select=title:%1".
 			format([workspace, fileName]);
 		var token = config.extensions.tiddlyspace.getCsrfToken();
 		var action = "%0?csrf_token=%1&redirect=%2"
@@ -96,7 +99,12 @@ var macro = config.macros.binaryUpload = {
 		// do not refactor following line... won't work in IE6 otherwise
 		$(place).append($('<iframe name="' + iframeName + '" id="' + iframeName + '"/>').css('display','none'));
 		macro.iFrameLoader(iframeName, function() {
-			options.callback(place, fileName, workspace, baseURL);
+			var content = document.getElementById(iframeName).contentWindow.document.documentElement;
+			if($(content).text().indexOf(fileName) > -1) {
+				options.callback(place, fileName, workspace, baseURL);
+			} else {
+				macro.errorHandler(fileName);
+			}
 			form.show(1000);
 			pleaseWait.hide(1000);
 		});
@@ -136,6 +144,7 @@ var macro = config.macros.binaryUpload = {
 			append('<div class="binaryUploadSubmit"><input type="submit" value="Upload" /></div>').
 			submit(function(ev) {
 				this.target = iframeName;
+				options.target = iframeName;
 				macro.uploadFile(place, baseURL, workspace, options);
 			});
 		$('<div />').addClass("uploadProgress").text(locale.uploadInProgress).hide().appendTo(place);
