@@ -1,6 +1,6 @@
 /***
 |''Name''|TiddlySpaceSpaces|
-|''Version''|0.5.6|
+|''Version''|0.5.8|
 |''Description''|TiddlySpace spaces management|
 |''Status''|@@beta@@|
 |''Source''|http://github.com/TiddlySpace/tiddlyspace/raw/master/src/plugins/TiddlySpaceSpaces.js|
@@ -38,7 +38,8 @@ var macro = config.macros.TiddlySpaceSpaces = { // TODO: rename
 		addLabel: "Create space",
 		addSuccess: "created space %0",
 		conflictError: "space <em>%0</em> already exists",
-		charError: "error: invalid space name - must only contain lowercase " +
+		charError: "error: invalid space name - must start with a letter, be " +
+			"at least two characters in length and only contain lowercase " +
 			"letters, digits or hyphens",
 		noSpaces: "you have no spaces",
 		addSpace: "creating your new space...",
@@ -47,9 +48,13 @@ var macro = config.macros.TiddlySpaceSpaces = { // TODO: rename
 
 	handler: function(place, macroName, params, wikifier, paramString, tiddler) {
 		var container = $("<div />").appendTo(place);
-		var mode = params[0] || "list";
+		var args = paramString.parseParams("anon")[0];
+		var mode = args.anon ? args.anon[0] : "list";
 		if(mode == "add") {
-			this.generateForm(container);
+			var options = {
+				subscribe: args.subscribe ? true : false
+			};
+			this.generateForm(container, options);
 		} else {
 			this.refresh(container);
 		}
@@ -84,7 +89,7 @@ var macro = config.macros.TiddlySpaceSpaces = { // TODO: rename
 			}
 		});
 	},
-	generateForm: function(container) {
+	generateForm: function(container, options) {
 		var locale = macro.locale;
 		$(this.formTemplate).submit(function(ev) {
 			$(".status", container).text(locale.addSpace).show();
@@ -95,6 +100,9 @@ var macro = config.macros.TiddlySpaceSpaces = { // TODO: rename
 		find("legend").text(this.locale.addLabel).end().
 		find(".annotation").hide().end().
 		find("[type=submit]").val(this.locale.addLabel).end().appendTo(container);
+		if(options.subscribe) {
+			$("[name=subscribe]", container).attr("checked", true);
+		}
 	},
 	onSubmit: function(ev) {
 		var target = ev.target;
